@@ -1,9 +1,9 @@
-#'Imports NMR Chemical Shift data from BMRB into R data frame
+#'Fetchs entry specific NMR chemical shift data from BMRB database
 #'
 #'Downloads NMR chemical shift data from BMRB database for a given Entry ID or list of Entry IDs
 #'@param BMRBidlist sinlge BMRB ID (or) list of BMRB IDs in csv format
 #'For metabolomics entries entry id should have 'bmse' prefix example: c('bmse000034','bmse000035','bmse000036')
-#'@return R data frame that contains relevant NMR chemical shifts from BMRB database
+#'@return R data frame that contains  Atom_chem_shift data for a given list of entries
 #'@export fetch_entry_chemical_shifts
 #'@examples
 #'df<-fetch_entry_chemical_shifts(15060)
@@ -12,7 +12,7 @@
 #'# Downloads NMR chemical shifts of multiple entries from BMRB
 #'df<-fetch_entry_chemical_shifts(c('bmse000034','bmse000035','bmse000036'))
 #'# Downloads data from BMRB metabolomics database
-#'@seealso \code{\link{fetch_atom_chemical_shifts}}
+#'@seealso \code{\link{fetch_atom_chemical_shifts}} and \code{\link{fetch_res_chemical_shifts}}
 fetch_entry_chemical_shifts<-function(BMRBidlist){
   bmrb_apiurl_json<-"http://webapi.bmrb.wisc.edu/v1/jsonrpc"
   query=rjson::toJSON(list(method='loop',jsonrpc='2.0',params=list(ids=BMRBidlist,keys=list('_Atom_chem_shift')),id=1))
@@ -48,6 +48,96 @@ fetch_entry_chemical_shifts<-function(BMRBidlist){
   return (cs_data)
 }
 
+#'Fetchs atom specific NMR chemical shift data from BMRB database
+#'
+#'Downloads the full list of chemical shifts from BMRB macromolecular/metabolomics database for a given atom
+#'@param atom atom name in NMR-STAR atom nomenclature ; Example: CA,CB2
+#'@param db macromolecules, metabolomics (optional, by default will fetch from macromolecules database)
+#'@return R data frame that contains full chemical shift list for a given atom
+#'@export fetch_atom_chemical_shifts
+#'@examples
+#'df<-fetch_atom_chemical_shifts('CG2','macromolecules')
+#'# Downloads CB2 chemical shifts from macromolecules database at BMRB
+#'df<-fetch_atom_chemical_shifts('C1','metabolomics')
+#'# Downloads C1 chemical shifts from metabolomics database at BMRB
+#'@seealso \code{\link{fetch_entry_chemical_shifts}},\code{\link{fetch_res_chemical_shifts}},\code{\link{filter_residue}} and \code{\link{chemical_shift_corr}}
+fetch_atom_chemical_shifts<-function(atom,db='macromolecules'){
+  bmrb_api<-"http://webapi.bmrb.wisc.edu/"
+  raw_data<-httr::GET(bmrb_api,path=paste0("/v1/rest/chemical_shifts/",atom,"/",db))
+  dat<-httr::content(raw_data,'parsed')
+  if (length(dat$data)==0){
+    warning('Atom or db wrong')
+    dat_frame<-NA
+  }else{
+    dat_tab<-data.table::as.data.table(dat$data)
+    dat_frame<-as.data.frame(data.table::data.table(t(dat_tab)))
+    for (name in names(dat_frame)){dat_frame[[name]]<-unlist(as.character(dat_frame[[name]]))}
+    dat_tags<-as.data.frame(data.table::data.table(t(data.table::as.data.table(dat$columns))))
+    for (i in 1:length(dat_tags$V1)){dat_tags$V1[i]<-strsplit(dat_tags$V1[i],"[.]")[[1]][2]}
+    colnames(dat_frame)<-dat_tags$V1
+    dat_frame$Val<-suppressWarnings(as.numeric(dat_frame$Val))
+    dat_frame$Val_err<-suppressWarnings(as.numeric(dat_frame$Val_err))
+  }
+  return(dat_frame)
+}
+
+#'Fetchs residue specific NMR chemical shift data from BMRB database
+#'
+#'Downloads the full list of chemical shifts from BMRB macromolecular database for a given amino acid (or) nucleic acid. Optionally particular atom can be specified in the parameter
+#'@param res residue name in NMR-STAR atom nomenclature ; Example: ALA,GLY ; default '*' (includes everything)
+#'@param atm atom name in NMR-STAR nomenclautre ; Example :CA,HB2; default * (includes all atoms)
+#'@return R data frame that contains full chemical shift list for a given atom
+#'@export fetch_res_chemical_shifts
+#'@examples
+#'#df<-fetch_res_chemical_shifts('GLY')
+#'# Downloads chemical shift data of all atoms of GLY
+#'#df<-fetch_res_chemical_shifts('ALA','CA')
+#'# Downloads C alpha chemical shifts of ALA from macromolecules database at BMRB
+#'@seealso \code{\link{fetch_atom_chemical_shifts}},\code{\link{filter_residue}} and \code{\link{chemical_shift_hist}}
+fetch_res_chemical_shifts<-function(res='*',atm='*'){
+  res=gsub('[*]','%',res)
+  atm=gsub('[*]','%',atm)
+  if (res=='*'){res="%"}
+  if (atm=='*'){atm="%"}
+  bmrb_apiurl_json<-"http://webapi.bmrb.wisc.edu/v1/jsonrpc"
+  query=rjson::toJSON(list(method='select',
+                           jsonrpc='2.0',
+                           params=list(database='macromolecules',
+                                       query=list(where=list(Comp_ID=res,Atom_ID=atm),
+                                                  select=list('Entry_ID','Entity_ID','Entity_assembly_ID','Comp_index_ID','Comp_ID','Atom_ID','Atom_type','Val','Val_err','Assigned_chem_shift_list_ID'),
+                                                  hash='false',
+                                                  from='Atom_chem_shift')),
+                           id=1))
+  rawdata<-httr::POST(bmrb_apiurl_json,encode='json',body=query)
+  dat<-httr::content(rawdata,'parsed')
+  if (length(dat$result)==0){
+    warning('Atom or db wrong')
+    dat_frame<-NA
+  }else{
+    dat_frame<-data.table::as.data.table(dat$result)
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Entry_ID"]="Entry_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Entity_ID"]="Entity_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Entity_assembly_ID"]="Entity_assembly_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Comp_index_ID"]="Comp_index_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Comp_ID"]="Comp_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Atom_ID"]="Atom_ID"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Atom_type"]="Atom_type"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Val"]="Val"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Val_err"]="Val_err"
+    names(dat_frame)[names(dat_frame)=="Atom_chem_shift.Assigned_chem_shift_list_ID"]="Assigned_chem_shift_list_ID"
+    dat_frame$Val=suppressWarnings(as.numeric(dat_frame$Val))
+    dat_frame$Val_err=suppressWarnings(as.character(dat_frame$Val_err))
+    dat_frame$Atom_ID=suppressWarnings(as.character(dat_frame$Atom_ID))
+    dat_frame$Comp_ID=suppressWarnings(as.character(dat_frame$Comp_ID))
+    dat_frame$Entry_ID=suppressWarnings(as.character(dat_frame$Entry_ID))
+    dat_frame$Entity_ID=suppressWarnings(as.character(dat_frame$Entity_ID))
+    dat_frame$Entity_assembly_ID=suppressWarnings(as.character(dat_frame$Entity_assembly_ID))
+    dat_frame$Comp_index_ID=suppressWarnings(as.numeric(dat_frame$Comp_index_ID))
+    dat_frame$Atom_type=suppressWarnings(as.character(dat_frame$Atom_type))
+    dat_frame$Assigned_chem_shift_list_ID=suppressWarnings(as.character(dat_frame$Assigned_chem_shift_list_ID))
+  }
+  return(dat_frame)
+}
 
 #'Reformats chemical shift dataframe for easy plotting
 #'
@@ -68,44 +158,111 @@ convert_cs_to_n15hsqc<-function(csdf){
     warning('No data')
     outdat<-NA
   }else{
+
+  #all amide proton nitrogen
   shiftH<-subset(csdf,Atom_ID=="H")
   names(shiftH)[names(shiftH)=="Val"]<-"H"
   shiftN<-subset(csdf,Atom_ID=="N")
   names(shiftN)[names(shiftN)=="Val"]<-"N"
+  shiftHNt<-merge(shiftH,shiftN,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+
+  #ARG side chain
+  shiftHH11<-subset(csdf,Atom_ID=="HH11")
+  names(shiftHH11)[names(shiftHH11)=="Val"]<-"H"
+  shiftHH12<-subset(csdf,Atom_ID=="HH12")
+  names(shiftHH12)[names(shiftHH12)=="Val"]<-"H"
+  shiftHH21<-subset(csdf,Atom_ID=="HH21")
+  names(shiftHH21)[names(shiftHH21)=="Val"]<-"H"
+  shiftHH22<-subset(csdf,Atom_ID=="HH22")
+  names(shiftHH22)[names(shiftHH22)=="Val"]<-"H"
+  shiftHE<-subset(csdf,Atom_ID=="HE")
+  names(shiftHE)[names(shiftHE)=="Val"]<-"H"
+  shiftNE<-subset(csdf,Atom_ID=="NE")
+  names(shiftNE)[names(shiftNE)=="Val"]<-"N"
+  shiftNH1<-subset(csdf,Atom_ID=="NH1")
+  names(shiftNH1)[names(shiftNH1)=="Val"]<-"N"
+  shiftNH2<-subset(csdf,Atom_ID=="NH2")
+  names(shiftNH2)[names(shiftNH2)=="Val"]<-"N"
+  shiftNEHE=merge(shiftHE,shiftNE,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNEHE)))){shiftNEHE$Comp_index_ID=paste(shiftNEHE$Comp_index_ID,"HE")}
+  shiftNHH11=merge(shiftHH11,shiftNH1,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHH11)))){shiftNHH11$Comp_index_ID=paste(shiftNHH11$Comp_index_ID,"HH11")}
+  shiftNHH12=merge(shiftHH12,shiftNH1,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHH12)))){shiftNHH12$Comp_index_ID=paste(shiftNHH12$Comp_index_ID,"HH12")}
+  shiftNHH21=merge(shiftHH21,shiftNH2,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHH21)))){shiftNHH21$Comp_index_ID=paste(shiftNHH21$Comp_index_ID,"HH21")}
+  shiftNHH22=merge(shiftHH22,shiftNH2,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHH22)))){shiftNHH22$Comp_index_ID=paste(shiftNHH22$Comp_index_ID,"HH22")}
+
+
+  #GLN sidechain
   shiftHE21<-subset(csdf,Atom_ID=="HE21")
   names(shiftHE21)[names(shiftHE21)=="Val"]<-"H"
   shiftHE22<-subset(csdf,Atom_ID=="HE22")
   names(shiftHE22)[names(shiftHE22)=="Val"]<-"H"
-  shiftHD21<-subset(csdf,Atom_ID=="HD21")
-  names(shiftHD21)[names(shiftHD21)=="Val"]<-"H"
-  shiftHD22<-subset(csdf,Atom_ID=="HD22")
-  names(shiftHD22)[names(shiftHD22)=="Val"]<-"H"
-  shiftHD1<-subset(csdf,Atom_ID=="HD1")
-  names(shiftHD1)[names(shiftHD1)=="Val"]<-"H"
-  shiftHE2<-subset(csdf,Atom_ID=="HE2")
-  names(shiftHE2)[names(shiftHE2)=="Val"]<-"H"
-  shiftND<-subset(csdf,Atom_ID=="ND2")
-  names(shiftND)[names(shiftND)=="Val"]<-"N"
   shiftNE<-subset(csdf,Atom_ID=="NE2")
   names(shiftNE)[names(shiftNE)=="Val"]<-"N"
-  shiftND1<-subset(csdf,Atom_ID=="ND1")
-  names(shiftND1)[names(shiftND1)=="Val"]<-"N"
-  shiftNE2<-subset(csdf,Atom_ID=="NE2")
-  names(shiftNE2)[names(shiftNE2)=="Val"]<-"N"
   shiftNEHE21=merge(shiftHE21,shiftNE,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
   if (!(all(is.na(shiftNEHE21)))){shiftNEHE21$Comp_index_ID=paste(shiftNEHE21$Comp_index_ID,"HE21")}
   shiftNEHE22=merge(shiftHE22,shiftNE,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
   if (!(all(is.na(shiftNEHE22)))){shiftNEHE22$Comp_index_ID=paste(shiftNEHE22$Comp_index_ID,"HE22")}
+
+  #ASN sidechain
+  shiftHD21<-subset(csdf,Atom_ID=="HD21")
+  names(shiftHD21)[names(shiftHD21)=="Val"]<-"H"
+  shiftHD22<-subset(csdf,Atom_ID=="HD22")
+  names(shiftHD22)[names(shiftHD22)=="Val"]<-"H"
+  shiftND<-subset(csdf,Atom_ID=="ND2")
+  names(shiftND)[names(shiftND)=="Val"]<-"N"
   shiftNDHD21=merge(shiftHD21,shiftND,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
   if (!(all(is.na(shiftNDHD21)))){shiftNDHD21$Comp_index_ID=paste(shiftNDHD21$Comp_index_ID,"HD21")}
   shiftNDHD22=merge(shiftHD22,shiftND,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
-  if (!(all(is.na(shiftNDHD22)))){shiftNDHD22$Comp_index_ID=paste(shiftNDHD22$Comp_index_ID,"ND22")}
+  if (!(all(is.na(shiftNDHD22)))){shiftNDHD22$Comp_index_ID=paste(shiftNDHD22$Comp_index_ID,"HD22")}
+
+  #HIS sidechain
+  shiftHD1<-subset(csdf,Atom_ID=="HD1")
+  names(shiftHD1)[names(shiftHD1)=="Val"]<-"H"
+  shiftND1<-subset(csdf,Atom_ID=="ND1")
+  names(shiftND1)[names(shiftND1)=="Val"]<-"N"
   shiftND1HD1=merge(shiftHD1,shiftND1,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
   if (!(all(is.na(shiftND1HD1)))){shiftND1HD1$Comp_index_ID=paste(shiftND1HD1$Comp_index_ID,"HD1")}
+  shiftHE2<-subset(csdf,Atom_ID=="HE2")
+  names(shiftHE2)[names(shiftHE2)=="Val"]<-"H"
+  shiftNE2<-subset(csdf,Atom_ID=="NE2")
+  names(shiftNE2)[names(shiftNE2)=="Val"]<-"N"
   shiftNE2HE2=merge(shiftHE2,shiftNE2,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
   if (!(all(is.na(shiftNE2HE2)))){shiftNE2HE2$Comp_index_ID=paste(shiftNE2HE2$Comp_index_ID,"HE2")}
-  shiftHNt<-merge(shiftH,shiftN,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
-  shiftHN<-rbind(rbind(rbind(rbind(rbind(rbind(shiftNEHE21,shiftNEHE22),shiftNDHD21),shiftNDHD22),shiftHNt),shiftND1HD1),shiftNE2HE2)
+
+  #TRP sidechain
+  shiftHE1<-subset(csdf,Atom_ID=="HE1")
+  names(shiftHE1)[names(shiftHE1)=="Val"]<-"H"
+  shiftNE1<-subset(csdf,Atom_ID=="NE1")
+  names(shiftNE1)[names(shiftNE1)=="Val"]<-"N"
+  shiftNE1HE1=merge(shiftHE1,shiftNE1,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNE1HE1)))){shiftNE1HE1$Comp_index_ID=paste(shiftNE1HE1$Comp_index_ID,"HE1")}
+
+
+  #LYS sidechain
+  shiftHZ<-subset(csdf,Atom_ID=="HZ")
+  names(shiftHZ)[names(shiftHZ)=="Val"]<-"H"
+  shiftHZ1<-subset(csdf,Atom_ID=="HZ1")
+  names(shiftHZ1)[names(shiftHZ1)=="Val"]<-"H"
+  shiftHZ2<-subset(csdf,Atom_ID=="HZ2")
+  names(shiftHZ2)[names(shiftHZ2)=="Val"]<-"H"
+  shiftHZ3<-subset(csdf,Atom_ID=="HZ3")
+  names(shiftHZ3)[names(shiftHZ3)=="Val"]<-"H"
+  shiftNZ<-subset(csdf,Atom_ID=="NZ")
+  names(shiftNZ)[names(shiftNZ)=="Val"]<-"N"
+  shiftNHZ=merge(shiftHZ,shiftNZ,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHZ)))){shiftNHZ$Comp_index_ID=paste(shiftNHZ$Comp_index_ID,"HZ")}
+  shiftNHZ1=merge(shiftHZ1,shiftNZ,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHZ1)))){shiftNHZ1$Comp_index_ID=paste(shiftNHZ1$Comp_index_ID,"HZ1")}
+  shiftNHZ2=merge(shiftHZ2,shiftNZ,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHZ2)))){shiftNHZ2$Comp_index_ID=paste(shiftNHZ2$Comp_index_ID,"HZ2")}
+  shiftNHZ3=merge(shiftHZ3,shiftNZ,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  if (!(all(is.na(shiftNHZ3)))){shiftNHZ3$Comp_index_ID=paste(shiftNHZ3$Comp_index_ID,"HZ3")}
+
+  shiftHN<-rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(rbind(shiftNEHE21,shiftNEHE22),shiftNDHD21),shiftNDHD22),shiftHNt),shiftND1HD1),shiftNE2HE2),shiftNEHE),shiftNHH11),shiftNHH12),shiftNHH21),shiftNHH22),shiftNHZ),shiftNHZ1),shiftNHZ2),shiftNHZ3),shiftNE1HE1)
   outdat<-shiftHN[,c("Entry_ID","Comp_index_ID","Entity_ID","Assigned_chem_shift_list_ID","Comp_ID.x","Comp_ID.y","H","N")]
   names(outdat)[names(outdat)=="Comp_ID.x"]<-"Comp_ID_H"
   names(outdat)[names(outdat)=="Comp_ID.y"]<-"Comp_ID_N"
@@ -142,7 +299,7 @@ convert_cs_to_tocsy<-function(csdf){
 
 #'Reformats chemical shift dataframe for easy plotting
 #'
-#'Reformats the output dataframe from \link{fetch_entry_chemical_shifts} into a simple dataframe that contains proton and carbon chemical shifts in tow columns.
+#'Reformats the output dataframe from \link{fetch_entry_chemical_shifts} into a simple dataframe that contains proton and carbon chemical shifts in two columns.
 #'This will be helpful to plot 1H-13C HSQC(Hetronuclear Single Quantum Coherence) spectrum
 #'@param csdf chemical shift data frame from \link{fetch_entry_chemical_shifts}
 #'@return R data frame that contains proton and carbon chemical shifts in two columns for each residue
@@ -366,39 +523,135 @@ convert_cs_to_c13hsqc<-function(csdf){
   })
 }
 
-#'NMR Chemical shifts list for a given atom from BMRB
+
+
+
+#'Plots chemical shift distribution
 #'
-#'Downloads the full list of chemical shifts from BMRB macromolecular/metabolomics database for a given atom
-#'@param atom atom name in NMR-STAR atom nomenclature ; Example: CA,CB2
-#'@param db macromolecules, metabolomics (optional, by default will fetch from macromolecules database)
-#'@return R data frame that contains full chemical shift list for a given atom
-#'@export fetch_atom_chemical_shifts
+#'Plots the histogram (or) density of  chemical shift distribution of a given amino acid (or) nucleic acid from BMRB database.  Optionally particular atom can be specified in the parameter
+#'@param res residue name in NMR-STAR atom nomenclature ; Example: ALA,GLY ; default '*' (includes everything)
+#'@param atm atom name in NMR-STAR nomenclautre ; Example :CA,HB2 default '*' (includes all atoms)
+#'@param type count ; other than count will assume density plot
+#'@param bw binwith for histogram; default value 0.1ppm
+#'@param cutoff values not with in the cutoff time standard deviation from both sides ofthe mean will be excluded from the plot;default value 8
+#'@param interactive TRUE/FALSE default TRUE
+#'@return R plot object
+#'@export chemical_shift_hist
 #'@examples
-#'df<-fetch_atom_chemical_shifts('CG2','macromolecules')
-#'# Downloads CB2 chemical shifts from macromolecules database at BMRB
-#'df<-fetch_atom_chemical_shifts('C1','metabolomics')
-#'# Downloads C1 chemical shifts from metabolomics database at BMRB
-#'@seealso \code{\link{fetch_entry_chemical_shifts}},\code{\link{filter_residue}} and \code{\link{chemical_shift_corr}}
-fetch_atom_chemical_shifts<-function(atom,db='macromolecules'){
-  bmrb_api<-"http://webapi.bmrb.wisc.edu/"
-  raw_data<-httr::GET(bmrb_api,path=paste0("/v1/rest/chemical_shifts/",atom,"/",db))
-  dat<-httr::content(raw_data,'parsed')
-  if (length(dat$data)==0){
-    warning('Atom or db wrong')
-    dat_frame<-NA
+#'#plt<-chemical_shift_hist('ALA')
+#'#plots the histogram of all atoms of ALA
+#'#plt<-chemical_shift_hist('GLY',type='density')
+#'#plots the density plot
+#'@seealso \code{\link{fetch_res_chemical_shifts}},\code{\link{filter_residue}} and \code{\link{chemical_shift_corr}}
+chemical_shift_hist<-function(res='*',atm='*',type='count',bw=0.1,cutoff=8,interactive=TRUE){
+  cs_dat2<-fetch_res_chemical_shifts(res,atm)
+  with(cs_dat2,{
+  if (all(is.na(cs_dat2))){
+    return(NA)
   }else{
-  dat_tab<-data.table::as.data.table(dat$data)
-  dat_frame<-as.data.frame(data.table::data.table(t(dat_tab)))
-  for (name in names(dat_frame)){dat_frame[[name]]<-unlist(as.character(dat_frame[[name]]))}
-  dat_tags<-as.data.frame(data.table::data.table(t(data.table::as.data.table(dat$columns))))
-  for (i in 1:length(dat_tags$V1)){dat_tags$V1[i]<-strsplit(dat_tags$V1[i],"[.]")[[1]][2]}
-  colnames(dat_frame)<-dat_tags$V1
-  dat_frame$Val<-suppressWarnings(as.numeric(dat_frame$Val))
-  dat_frame$Val_err<-suppressWarnings(as.numeric(dat_frame$Val_err))
+    for (atom in unique(cs_dat2$Atom_ID)){
+      ss<-stats::sd(subset(cs_dat2,Atom_ID==atom)$Val)
+      m<-mean(subset(cs_dat2,Atom_ID==atom)$Val)
+      min_val<-m-(ss*cutoff)
+      max_val<-m+(ss*cutoff)
+      if (exists('cs_dat')){
+        cs_dat<-rbind(cs_dat,subset(cs_dat2, Val>=min_val & Val<=max_val))
+      }else{
+        cs_dat<-subset(cs_dat2, Val>=min_val & Val<=max_val)
+      }
+    }
+    if (type=='count'){
+      plt<-ggplot2::ggplot(cs_dat)+
+        ggplot2::geom_histogram(ggplot2::aes(x=Val,color=Atom_ID,fill=Atom_ID),binwidth=bw,position = 'identity',alpha=0.7)+
+        ggplot2::xlab("Chemical shift")+
+        ggplot2::ylab("Count")+
+        ggplot2::labs(color="",fill="")
+    } else{
+      plt<-ggplot2::ggplot(cs_dat)+
+        ggplot2::geom_density(ggplot2::aes(x=Val,color=Atom_ID,fill=Atom_ID),alpha=0.7,trim=T)+
+        ggplot2::xlab("Chemical shift")+
+        ggplot2::ylab("Density")+
+        ggplot2::labs(color="",fill="")
+    }
+    if (interactive){
+      plt2<-plotly::plotly_build(plt)
+    }else{
+      plt2<-plt
+    }
   }
-  return(dat_frame)
+  return(plt2)
+  })
 }
 
+#'Plots chemical shift distribution for a list of atoms
+#'
+#'Plots the histogram (or) density of  chemical shift distribution of a given list of atoms. Atoms from different residues cam be specified as "residue-atom". Exammple "ALA-CA","GLN-HE21","GLN-HE*"
+#'@param atm list Example: c("ALA-CA","GLY-CA")
+#'@param type count ; other than count will assume density plot
+#'@param bw binwith for histogram; default value 0.1ppm
+#'@param cutoff values not with in the cutoff time standard deviation from both sides ofthe mean will be excluded from the plot;default value 8
+#'@param interactive TRUE/FALSE default TRUE
+#'@return R plot object
+#'@export chemical_shift_hists
+#'@examples
+#'#plt<-chemical_shift_hists(c('ALA-C*'))
+#'#plots the histogram of all atoms of ALA
+#'#plt<-chemical_shift_hists(c("GLY-H*","ALA-HA"),type='density')
+#'#plots the density plot
+#'@seealso \code{\link{fetch_res_chemical_shifts}},\code{\link{filter_residue}} and \code{\link{chemical_shift_corr}}
+chemical_shift_hists<-function(atm=NA,type='count',bw=0.1,cutoff=8,interactive=TRUE){
+  for (atom in atm){
+    res<-strsplit(atom,"-")[[1]][1]
+    at<-strsplit(atom,"-")[[1]][2]
+    if (exists('cs_dat2')){
+      cs_dat2<-rbind(cs_dat2,fetch_res_chemical_shifts(res,at))
+    }else{
+      cs_dat2<-fetch_res_chemical_shifts(res,at)
+    }
+  }
+  with(cs_dat2,{
+  #cs_dat2<-fetch_res_chemical_shifts(res,atm)
+  if (all(is.na(cs_dat2))){
+    return(NA)
+  }else{
+    for (atom in unique(cs_dat2$Atom_ID)){
+      ss<-stats::sd(subset(cs_dat2,Atom_ID==atom)$Val)
+      m<-mean(subset(cs_dat2,Atom_ID==atom)$Val)
+      min_val<-m-(ss*cutoff)
+      max_val<-m+(ss*cutoff)
+      if (exists('cs_dat')){
+        cs_dat<-rbind(cs_dat,subset(cs_dat2, Val>=min_val & Val<=max_val))
+      }else{
+        cs_dat<-subset(cs_dat2, Val>=min_val & Val<=max_val)
+      }
+    }
+    if (type=='count'){
+      plt<-ggplot2::ggplot(cs_dat)+
+        ggplot2::geom_histogram(ggplot2::aes(x=Val,color=Atom_ID,fill=Comp_ID),binwidth=bw,position = 'identity',alpha=0.7)+
+        ggplot2::xlab("Chemical shift")+
+        ggplot2::ylab("Count")+
+        ggplot2::labs(color="",fill="")
+    } else{
+      plt<-ggplot2::ggplot(cs_dat)+
+        ggplot2::geom_density(ggplot2::aes(x=Val,color=Atom_ID,fill=Comp_ID),alpha=0.7,trim=T)+
+        ggplot2::xlab("Chemical shift")+
+        ggplot2::ylab("Density")+
+        ggplot2::labs(color="",fill="")
+    }
+    if (interactive){
+      plt2<-plotly::plotly_build(plt)
+    }else{
+      plt2<-plt
+    }
+  }
+  return(plt2)
+  })
+}
+
+
+
+
+
 #'Simulates H1-N15 HSQC spectra for a given entry or list of entries from BMRB
 #'
 #'Simulates H1-N15 HSQC(Hetronuclear Single Quantum Coherence) spectra directly from BMRB database. Default plot type will be 'scatter'.Peaks from different spectra(entries) can be connected based on residue numbers by specifying plot type as 'line'.
@@ -432,37 +685,37 @@ HSQC_15N<-function(idlist,type='scatter',interactive=TRUE){
   if (type=='scatter'){
     if (length(idlist)>1){
       if (interactive){
-    plt<-ggplot2::ggplot(hsqc_data)+
-    ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+ggplot2::labs(color="")
+    plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
+    ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+ggplot2::labs(color=""))
       #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
       }else{
-        plt<-ggplot2::ggplot(hsqc_data)+
+        plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
           ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+
-          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
       }
     }else{
       if (interactive){
-      plt<-ggplot2::ggplot(hsqc_data)+
-        ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Comp_ID_H,label=Info))+ggplot2::labs(color="")
+      plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
+        ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Comp_ID_H,label=Info))+ggplot2::labs(color=""))
         #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
       }else{
-        plt<-ggplot2::ggplot(hsqc_data)+
+        plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
           ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Comp_ID_H,label=Info))+
-          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
       }
     }
 
   } else {
     if (interactive){
-    plt<-ggplot2::ggplot(hsqc_data)+
+    plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
     ggplot2::geom_line(ggplot2::aes(x=H,y=N,group=Comp_index_ID,label=Info))+
-    ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+ggplot2::labs(color="")
+    ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+ggplot2::labs(color=""))
      # ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
     }else{
-      plt<-ggplot2::ggplot(hsqc_data)+
+      plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
         ggplot2::geom_line(ggplot2::aes(x=H,y=N,group=Comp_index_ID,label=Info))+
         ggplot2::geom_point(ggplot2::aes(x=H,y=N,color=Entry_ID,label=Info))+
-        ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+        ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
     }
   }
   if (interactive){
@@ -510,37 +763,37 @@ HSQC_13C<-function(idlist,type='scatter',interactive=TRUE){
         if (type=='scatter'){
           if (length(idlist)>1){
             if (interactive){
-              plt<-ggplot2::ggplot(hsqc_data)+
-                ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+ggplot2::labs(color="")
+              plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
+                ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+ggplot2::labs(color=""))
               #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
             }else{
-              plt<-ggplot2::ggplot(hsqc_data)+
+              plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
                 ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+
-                ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+                ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
             }
           }else{
             if (interactive){
-              plt<-ggplot2::ggplot(hsqc_data)+
-                ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Comp_ID_H,label=Info))+ggplot2::labs(color="")
+              plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
+                ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Comp_ID_H,label=Info))+ggplot2::labs(color=""))
               #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
             }else{
-              plt<-ggplot2::ggplot(hsqc_data)+
+              plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
                 ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Comp_ID_H,label=Info))+
-                ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+                ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
             }
           }
 
         } else {
           if (interactive){
-            plt<-ggplot2::ggplot(hsqc_data)+
+            plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
               ggplot2::geom_line(ggplot2::aes(x=H,y=C,group=Comp_index_ID,label=Info))+
-              ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+ggplot2::labs(color="")
+              ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+ggplot2::labs(color=""))
             # ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()
           }else{
-            plt<-ggplot2::ggplot(hsqc_data)+
+            plt<-suppressWarnings(ggplot2::ggplot(hsqc_data)+
               ggplot2::geom_line(ggplot2::aes(x=H,y=C,group=Comp_index_ID,label=Info))+
               ggplot2::geom_point(ggplot2::aes(x=H,y=C,color=Entry_ID,label=Info))+
-              ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")
+              ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color=""))
           }
         }
         if (interactive){
@@ -554,6 +807,68 @@ HSQC_13C<-function(idlist,type='scatter',interactive=TRUE){
       return(plt2)})}
 }
 
+#'Simulates TOCSY spectra for a given entry or a list of entries from BMRB
+#'
+#'Simulates TOCSY(TOtal Correlation SpectroscopY) spectra directly from BMRB database. By default it will generate interactive graphics using plotly library
+#'@param idlist list of bmrb ids c(17074,17076,17077)
+#'@param interactive TRUE/FALSE default=TRUE
+#'@return plot object
+#'@export TOCSY
+#'@examples
+#'plot_tocsy<-TOCSY(c(17074,17076,17077))
+#'#Simulates TOCSY spectra for the given 3 entries
+#'plot_tocsy<-TOCSY(c(17074,17076,17077),interactive=FALSE)
+#'# Example to disable interactive plot feature
+#'@seealso \code{\link{HSQC_15N}} and \code{\link{HSQC_13C}}
+TOCSY<-function(idlist,interactive=TRUE){
+  cs<-fetch_entry_chemical_shifts(idlist)
+  with(cs,{cs_h<-subset(cs,Atom_type=="H")
+  tocsy_data<-merge(cs_h,cs_h,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
+  with(tocsy_data,{
+    if (all(is.na(tocsy_data))){
+      warning('No data')
+      plt2<-NA}
+    else{
+      tocsy_data$Info=NA
+      tocsy_data$Info=paste(tocsy_data$Comp_index_ID,tocsy_data$Entity_ID,tocsy_data$Comp_ID.x,tocsy_data$Atom_ID.x,tocsy_data$Atom_ID.y,tocsy_data$Assigned_chem_shift_list_ID,sep=",")
+      if (length(idlist)>1){
+        if (interactive){
+          plt<-suppressWarnings(ggplot2::ggplot(tocsy_data)+
+                                  ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Entry_ID,label=Info))+
+                                  #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
+                                  ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color=""))
+        }else{
+          plt<-suppressWarnings(ggplot2::ggplot(tocsy_data)+
+                                  ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Entry_ID,label=Info))+
+                                  ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
+                                  ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color=""))
+        }
+      }else{
+        if (interactive){
+          plt<-suppressWarnings(ggplot2::ggplot(tocsy_data)+
+                                  ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID.x,label=Info))+
+                                  #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
+                                  ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color=""))
+        }else{
+          plt<-suppressWarnings(ggplot2::ggplot(tocsy_data)+
+                                  ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID.x,label=Info))+
+                                  ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")+
+                                  ggplot2::xlab("H")+ggplot2::ylab("H"))
+        }
+      }
+      if (interactive){
+        plt2<-plotly::plotly_build(plt)
+        plt2$x$layout$xaxis$autorange = "reversed"
+        plt2$x$layout$yaxis$autorange = "reversed"}
+      else{
+        plt2<-plt
+      }
+    }
+    return(plt2)
+  })})
+}
+
+
 
 #'Chemical shift correlation between any two atoms from a single residue
 #'
@@ -593,20 +908,20 @@ chemical_shift_corr<-function(atom1,atom2,res=NA,type="c",interactive=TRUE){
   names(cs)[names(cs)=="Comp_ID.y"]<-"Comp_ID_2"
   names(cs)[names(cs)=="Atom_ID.x"]<-"Atom_ID_1"
   names(cs)[names(cs)=="Atom_ID.y"]<-"Atom_ID_2"
-  xl1=mean(cs$Val.x)-5*sd(cs$Val.x)
-  xl2=mean(cs$Val.x)+5*sd(cs$Val.x)
-  yl1=mean(cs$Val.y)-5*sd(cs$Val.y)
-  yl2=mean(cs$Val.y)+5*sd(cs$Val.y)
+  xl1=mean(cs$Val.x)-5*stats::sd(cs$Val.x)
+  xl2=mean(cs$Val.x)+5*stats::sd(cs$Val.x)
+  yl1=mean(cs$Val.y)-5*stats::sd(cs$Val.y)
+  yl2=mean(cs$Val.y)+5*stats::sd(cs$Val.y)
   cs<-subset(cs,(Val.x>xl1 & Val.x<xl2 & Val.y>yl1 & Val.y<yl2))
-  names(cs)[names(cs)=="Val.x"]<-atom1
-  names(cs)[names(cs)=="Val.y"]<-atom2
+  #names(cs)[names(cs)=="Val.x"]<-atom1
+  #names(cs)[names(cs)=="Val.y"]<-atom2
   cs$Info=paste(cs$Comp_index_ID,cs$Entity_ID,cs$Atom_ID_1,cs$Atom_ID_2,cs$Assigned_chem_shift_list_ID,sep=",")
   if (type=="c"){
     if (interactive){
   plt<-ggplot2::ggplot(cs)+
     #ggplot2::geom_density_2d(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1))+
     #ggplot2::stat_density_2d(geom='polygon',ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),fill= Comp_ID_1),bins=500)+
-    ggplot2::geom_density_2d(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1),bins=100)+
+    ggplot2::geom_density_2d(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID_1),bins=100)+
     #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
     ggplot2::xlab(atom1)+
     ggplot2::ylab(atom2)+ggplot2::labs(color="")
@@ -614,7 +929,7 @@ chemical_shift_corr<-function(atom1,atom2,res=NA,type="c",interactive=TRUE){
       plt<-ggplot2::ggplot(cs)+
         #ggplot2::geom_density_2d(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1))+
         #ggplot2::stat_density_2d(geom='polygon',ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),fill= Comp_ID_1),bins=500)+
-        ggplot2::geom_density_2d(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1),bins=100)+
+        ggplot2::geom_density_2d(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID_1),bins=100)+
         ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
         ggplot2::xlab(atom1)+
         ggplot2::ylab(atom2)+ggplot2::labs(color="")
@@ -623,13 +938,13 @@ chemical_shift_corr<-function(atom1,atom2,res=NA,type="c",interactive=TRUE){
   else{
     if (interactive){
     plt<-ggplot2::ggplot(cs)+
-      ggplot2::geom_point(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1))+
+      ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID_1))+
       #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
       ggplot2::xlab(atom1)+
       ggplot2::ylab(atom2)+ggplot2::labs(color="")
     }else{
       plt<-ggplot2::ggplot(cs)+
-        ggplot2::geom_point(ggplot2::aes(x=eval(as.name(atom1)),y=eval(as.name(atom2)),color=Comp_ID_1))+
+        ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID_1))+
         ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
         ggplot2::xlab(atom1)+
         ggplot2::ylab(atom2)+ggplot2::labs(color="")
@@ -699,64 +1014,3 @@ filter_residue<-function(df){
 
 
 
-#'Simulates TOCSY spectra for a given entry or a list of entries from BMRB
-#'
-#'Simulates TOCSY(TOtal Correlation SpectroscopY) spectra directly from BMRB database. By default it will generate interactive graphics using plotly library
-#'@param idlist list of bmrb ids c(17074,17076,17077)
-#'@param interactive TRUE/FALSE default=TRUE
-#'@return plot object
-#'@export TOCSY
-#'@examples
-#'plot_tocsy<-TOCSY(c(17074,17076,17077))
-#'#Simulates TOCSY spectra for the given 3 entries
-#'plot_tocsy<-TOCSY(c(17074,17076,17077),interactive=FALSE)
-#'# Example to disable interactive plot feature
-#'@seealso \code{\link{HSQC_15N}} and \code{\link{HSQC_13C}}
-TOCSY<-function(idlist,interactive=TRUE){
-  cs<-fetch_entry_chemical_shifts(idlist)
-  with(cs,{cs_h<-subset(cs,Atom_type=="H")
-  tocsy_data<-merge(cs_h,cs_h,by=c('Entry_ID','Entity_ID','Comp_index_ID','Assigned_chem_shift_list_ID'))
-  with(tocsy_data,{
-  if (all(is.na(tocsy_data))){
-    warning('No data')
-    plt2<-NA}
-  else{
-    tocsy_data$Info=NA
-    tocsy_data$Info=paste(tocsy_data$Comp_index_ID,tocsy_data$Entity_ID,tocsy_data$Comp_ID.x,tocsy_data$Atom_ID.x,tocsy_data$Atom_ID.y,tocsy_data$Assigned_chem_shift_list_ID,sep=",")
-    if (length(idlist)>1){
-      if (interactive){
-      plt<-ggplot2::ggplot(tocsy_data)+
-        ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Entry_ID,label=Info))+
-        #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
-        ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color="")
-      }else{
-        plt<-ggplot2::ggplot(tocsy_data)+
-          ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Entry_ID,label=Info))+
-          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
-          ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color="")
-      }
-    }else{
-      if (interactive){
-      plt<-ggplot2::ggplot(tocsy_data)+
-        ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID.x,label=Info))+
-        #ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+
-        ggplot2::xlab("H")+ggplot2::ylab("H")+ggplot2::labs(color="")
-      }else{
-        plt<-ggplot2::ggplot(tocsy_data)+
-          ggplot2::geom_point(ggplot2::aes(x=Val.x,y=Val.y,color=Comp_ID.x,label=Info))+
-          ggplot2::scale_y_reverse()+ggplot2::scale_x_reverse()+ggplot2::labs(color="")+
-          ggplot2::xlab("H")+ggplot2::ylab("H")
-      }
-    }
-    if (interactive){
-      plt2<-plotly::plotly_build(plt)
-      plt2$x$layout$xaxis$autorange = "reversed"
-      plt2$x$layout$yaxis$autorange = "reversed"}
-    else{
-      plt2<-plt
-    }
-  }
-  return(plt2)
-})})
-}
-
